WireSchema

Trait WireSchema 

pub trait WireSchema {
    const REQUIRES_ARITY: bool = false;

    // Required method
    fn wire_schema() -> Vec<u8> ;
}
Stable, versioned identity for persisted payloads, independent of Rust names. External implementations must use a globally unique schema and change it when the wire interpretation changes. Never reuse a built-in safemesh/ identity.

Provided Associated Constants

const REQUIRES_ARITY: bool = false

Required Methods

fn wire_schema() -> Vec<u8>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl WireSchema for EnableWinsFlag<u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for EnableWinsFlagDelta<u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for GCounterDelta

Source

const REQUIRES_ARITY: bool = true

Source

impl WireSchema for GSet<u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for LwwMap<u64, u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for LwwMapDelta<u64, u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for LwwRegister<u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for LwwRegisterDelta<u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for OrSet<u64, u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for OrSetDelta<String, u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for OrSetDelta<u64, u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl WireSchema for PnCounterDelta

Source

const REQUIRES_ARITY: bool = true

Source

impl WireSchema for Rga<u64, u64>

Source

const REQUIRES_ARITY: bool = false

Source

impl<D: WireSchema> WireSchema for EventLog<D>

Source

impl<D: WireSchema> WireSchema for Record<D>