Mergeable

Trait Mergeable 

pub trait Mergeable {
    // Required method
    fn merge(&mut self, other: &Self);
}
State-based merge contract: merge is expected to be a semilattice join.

For in-house types, this contract is backed by the Lean proof suite and differential conformance corpus. For user-defined types, it is a tested contract enforced by the laws harness, not a proof.

Required Methods

fn merge(&mut self, other: &Self)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Mergeable for GCounter

Source

impl Mergeable for PnCounter

Source

impl<K: Ord + Clone, V: Ord + Clone> Mergeable for LwwMap<K, V>

Source

impl<K: Ord + Clone> Mergeable for EnableWinsFlag<K>

Source

impl<P: Ord + Clone, V: Ord + Clone> Mergeable for Rga<P, V>

Source

impl<T: Ord + Clone, K: Ord + Clone> Mergeable for OrSet<T, K>

Source

impl<T: Ord + Clone> Mergeable for GSet<T>

Source

impl<V: Ord + Clone> Mergeable for LwwRegister<V>