pub struct GCounterDelta {
pub replica: usize,
pub tally: u64,
}Expand description
Delta for a grow-only counter: one replica coordinate and its asserted tally.
Fields
replica: usizetally: u64Trait Implementations
Sourceimpl Clone for GCounterDelta
impl Clone for GCounterDelta
Sourcefn clone(&self) -> GCounterDelta
fn clone(&self) -> GCounterDelta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GCounterDelta
impl Debug for GCounterDelta
impl Eq for GCounterDelta
Sourceimpl OwnedDelta for GCounterDelta
impl OwnedDelta for GCounterDelta
fn owned_payload(&self) -> OwnedPayload
Sourceimpl PartialEq for GCounterDelta
impl PartialEq for GCounterDelta
Sourcefn eq(&self, other: &GCounterDelta) -> bool
fn eq(&self, other: &GCounterDelta) -> bool
Tests for
self and other values to be equal, and is used by ==.1.0.0 (const: unstable) · Sourcefn ne(&self, other: &Rhs) -> bool
fn ne(&self, other: &Rhs) -> bool
Tests for
!=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.impl StructuralPartialEq for GCounterDelta
Sourceimpl WireDecode for GCounterDelta
impl WireDecode for GCounterDelta
fn decode_wire(cursor: &mut WireCursor<'_>) -> Result<Self, WireError>
fn from_wire_bytes(bytes: &[u8]) -> Result<Self, WireError>
Sourceimpl WireEncode for GCounterDelta
impl WireEncode for GCounterDelta
fn encode_wire(&self, out: &mut Vec<u8>) -> Result<(), WireError>
fn to_wire_bytes(&self) -> Result<Vec<u8>, WireError>
Sourceimpl WireSchema for GCounterDelta
impl WireSchema for GCounterDelta
const REQUIRES_ARITY: bool = true
fn wire_schema() -> Vec<u8> ⓘ