pub struct LwwEntry<V: Ord> {
pub dot: LwwDot,
pub value: V,
}Expand description
One LWW register assignment.
Fields
dot: LwwDotvalue: VTrait Implementations
impl<V: Eq + Ord> Eq for LwwEntry<V>
Sourceimpl<V: Ord + Ord> Ord for LwwEntry<V>
impl<V: Ord + Ord> Ord for LwwEntry<V>
Sourcefn cmp(&self, other: &LwwEntry<V>) -> Ordering
fn cmp(&self, other: &LwwEntry<V>) -> Ordering
This method returns an
Ordering between self and other. Read more1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
1.50.0 (const: unstable) · Sourcefn clamp(self, min: Self, max: Self) -> Selfwhere
Self: Sized,
fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: Sized,
Restrict a value to a certain interval. Read more
Sourceimpl<V: PartialEq + Ord> PartialEq for LwwEntry<V>
impl<V: PartialEq + Ord> PartialEq for LwwEntry<V>
Sourcefn eq(&self, other: &LwwEntry<V>) -> bool
fn eq(&self, other: &LwwEntry<V>) -> bool
Tests for
self and other values to be equal, and is used by ==.1.0.0 (const: unstable) · Sourcefn ne(&self, other: &Rhs) -> bool
fn ne(&self, other: &Rhs) -> bool
Tests for
!=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.Sourceimpl<V: PartialOrd + Ord> PartialOrd for LwwEntry<V>
impl<V: PartialOrd + Ord> PartialOrd for LwwEntry<V>
Sourcefn partial_cmp(&self, other: &LwwEntry<V>) -> Option<Ordering>
fn partial_cmp(&self, other: &LwwEntry<V>) -> Option<Ordering>
This method returns an ordering between
self and other values if one exists. Read more1.0.0 (const: unstable) · Sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
Tests less than (for
self and other) and is used by the < operator. Read more1.0.0 (const: unstable) · Sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
Tests less than or equal to (for
self and other) and is used by the
<= operator. Read more1.0.0 (const: unstable) · Sourcefn gt(&self, other: &Rhs) -> bool
fn gt(&self, other: &Rhs) -> bool
Tests greater than (for
self and other) and is used by the >
operator. Read more1.0.0 (const: unstable) · Sourcefn ge(&self, other: &Rhs) -> bool
fn ge(&self, other: &Rhs) -> bool
Tests greater than or equal to (for
self and other) and is used by
the >= operator. Read moreimpl<V: PartialEq + Ord> StructuralPartialEq for LwwEntry<V>