pub struct LwwRegisterDelta<V: Ord> {
pub timestamp: u64,
pub replica: u64,
pub value: V,
}Expand description
Delta for a last-writer-wins register.
Fields
timestamp: u64replica: u64value: VTrait Implementations
Sourceimpl<V: Clone + Ord> Clone for LwwRegisterDelta<V>
impl<V: Clone + Ord> Clone for LwwRegisterDelta<V>
Sourcefn clone(&self) -> LwwRegisterDelta<V>
fn clone(&self) -> LwwRegisterDelta<V>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<V: Debug + Ord> Debug for LwwRegisterDelta<V>
impl<V: Debug + Ord> Debug for LwwRegisterDelta<V>
impl<V: Eq + Ord> Eq for LwwRegisterDelta<V>
Sourceimpl<V: PartialEq + Ord> PartialEq for LwwRegisterDelta<V>
impl<V: PartialEq + Ord> PartialEq for LwwRegisterDelta<V>
Sourcefn eq(&self, other: &LwwRegisterDelta<V>) -> bool
fn eq(&self, other: &LwwRegisterDelta<V>) -> bool
Tests for
self and other values to be equal, and is used by ==.1.0.0 (const: unstable) · Sourcefn ne(&self, other: &Rhs) -> bool
fn ne(&self, other: &Rhs) -> bool
Tests for
!=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.impl<V: PartialEq + Ord> StructuralPartialEq for LwwRegisterDelta<V>
Sourceimpl WireDecode for LwwRegisterDelta<u64>
impl WireDecode for LwwRegisterDelta<u64>
fn decode_wire(cursor: &mut WireCursor<'_>) -> Result<Self, WireError>
fn from_wire_bytes(bytes: &[u8]) -> Result<Self, WireError>
Sourceimpl WireEncode for LwwRegisterDelta<u64>
impl WireEncode for LwwRegisterDelta<u64>
fn encode_wire(&self, out: &mut Vec<u8>) -> Result<(), WireError>
fn to_wire_bytes(&self) -> Result<Vec<u8>, WireError>
Sourceimpl WireSchema for LwwRegisterDelta<u64>
impl WireSchema for LwwRegisterDelta<u64>
const REQUIRES_ARITY: bool = false
fn wire_schema() -> Vec<u8> ⓘ