pub struct LawFailure {
pub law: Law,
pub a: usize,
pub b: Option<usize>,
pub c: Option<usize>,
}Fields
law: Lawa: usizeb: Option<usize>c: Option<usize>Trait Implementations
Sourceimpl Clone for LawFailure
impl Clone for LawFailure
Sourcefn clone(&self) -> LawFailure
fn clone(&self) -> LawFailure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LawFailure
Sourceimpl Debug for LawFailure
impl Debug for LawFailure
impl Eq for LawFailure
Sourceimpl PartialEq for LawFailure
impl PartialEq for LawFailure
Sourcefn eq(&self, other: &LawFailure) -> bool
fn eq(&self, other: &LawFailure) -> bool
Tests for
self and other values to be equal, and is used by ==.1.0.0 (const: unstable) · Sourcefn ne(&self, other: &Rhs) -> bool
fn ne(&self, other: &Rhs) -> bool
Tests for
!=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.impl StructuralPartialEq for LawFailure