pub struct WriteContext {
pub config: WriterConfig,
pub held: bool,
pub generation: u64,
pub current_generation: u64,
pub local: bool,
}Expand description
Facts supplied by the local fence, not by a remote packet. Public for oracle conformance; constructing these facts does not grant a local writer lease.
Fields
config: WriterConfigheld: boolgeneration: u64current_generation: u64local: boolTrait Implementations
Sourceimpl Clone for WriteContext
impl Clone for WriteContext
Sourcefn clone(&self) -> WriteContext
fn clone(&self) -> WriteContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WriteContext
Sourceimpl Debug for WriteContext
impl Debug for WriteContext